from typing import List, Dict
from models.verse import Verse
from models.verse_categories import VerseCategory

class VerseAnalytics:
    @staticmethod
    def get_category_distribution(verses: List[Verse]) -> Dict[VerseCategory, int]:
        pass
        
    @staticmethod
    def get_review_recommendations(verses: List[Verse]) -> List[Verse]:
        pass